@@ -22,7 +22,13 @@ class InvalidFieldsParam(APIException):
     default_detail = 'Invalid fields param, fields must be a list'
 
 
-class NotDataException(APIException):
+class NotDataEverException(APIException):
     status_code = 400
     default_code = 'no data'
     default_detail = 'no data ever'
+
+
+class NotDataException(APIException):
+    status_code = 205
+    default_code = 'no data'
+    default_detail = 'no data for this params'
\ No newline at end of file
