@@ -111,8 +111,10 @@ class CredentialMixin(BaseCredentialMixin):
             params = {
                 '_id': cred_id,
             }
-
-            credential = model.querybuilder.find_one(**params)
+            model_querybuilder = getattr(model, 'Q', None) or getattr(
+                model, 'querybuilder'
+            )
+            credential = model_querybuilder.find_one(**params)
         if not credential:
             raise PermissionDenied(
                 {"status": "error", "message": "Credential does not exist."}
@@ -127,7 +129,7 @@ class CredentialMixin(BaseCredentialMixin):
             self.smart_username = user_info['username']
             if hasattr(settings, 'CREDENTIAL_MODEL') and self.check_credential:
                 self.credential = self.get_credential(request)
-        return super().initial(request, *args, **kwargs)
+        return super().initial(request, *args, **kwargs)  # type: ignore
 
     def get_credential_model(self):
         if hasattr(settings, 'CREDENTIAL_MODEL'):
@@ -140,4 +142,4 @@ class CredentialMixin(BaseCredentialMixin):
 class SmartAdminRequiredMixin(BaseCredentialMixin):
     def initial(self, request, *args, **kwargs):
         self.get_check_admin(request)
-        return super().initial(request, *args, **kwargs)
+        return super().initial(request, *args, **kwargs)  # type: ignore
