@@ -5,7 +5,6 @@ from rest_framework.response import Response
 from rest_framework.exceptions import PermissionDenied
 from rest_framework.views import APIView
 
-from .exceptions import InvalidDateParams, InvalidFieldsParam
 from .mixins import CredentialMixin
 from .pagination import LimitOffsetPaginationListAPIView
 
@@ -14,7 +13,6 @@ __all__ = (
     'BaseCredentialModelViewSet',
     'BaseReportListAPIView',
     'BaseGetCredentialAPIView',
-    'BaseStatTSVAPIView',
 )
 
 
@@ -95,7 +93,7 @@ class BaseReportListAPIView(LimitOffsetPaginationListAPIView):
 class BaseGetCredentialAPIView(CredentialMixin, APIView):
     def get_redirect_uri(self):
         """Create in this method redirect uri
-            Example: https://oauth.yandex.ru/authorize?response_type=code&client_id={settings.YANDEX_APP_CLIENT_ID}&state={self.get_state()}&redirect_uri={redirect_url}
+        Example: https://oauth.yandex.ru/authorize?response_type=code&client_id={settings.YANDEX_APP_CLIENT_ID}&state={self.get_state()}&redirect_uri={redirect_url}
         """
         raise NotImplementedError()
 
@@ -113,21 +111,21 @@ class BaseGetCredentialAPIView(CredentialMixin, APIView):
 
     def get_state(self):
         """
-            Create state in this method
-            Excample:
-                user_info = self.get_user_info(request, get_token=True)
-                user_id = user_info["id"]
-                main_user = user_info["username"]
-                # user_id = 16
-                # main_user = "main_user"
+        Create state in this method
+        Excample:
+            user_info = self.get_user_info(request, get_token=True)
+            user_id = user_info["id"]
+            main_user = user_info["username"]
+            # user_id = 16
+            # main_user = "main_user"
 
-                state = {
-                    "callback_url": request.GET['callback_url'],
-                    "user_id": user_id,
-                    "main_user": main_user,
-                    "platform_id": request.GET['platform_id']
-                }
-                return state
+            state = {
+                "callback_url": request.GET['callback_url'],
+                "user_id": user_id,
+                "main_user": main_user,
+                "platform_id": request.GET['platform_id']
+            }
+            return state
         """
         raise NotImplemented()
 
@@ -147,81 +145,17 @@ class HomeAPIView(CredentialMixin, APIView):
         return Response({"status": "success", "message": "smart integration api"})
 
 
-class BaseStatTSVAPIView(CredentialMixin, APIView):
-    check_credential = False
-    serializer_class = None
-
-    def get_serializer_class(self):
-        if not self.serializer_class:
-            raise NotImplementedError('serializer_class must be implemented!')
-        return self.serializer_class
-
-    def check_log(self, *args, **kwargs) -> None:
-        """check any download log,
-
-        Returns:
-            None: or raise APIException
-        """
-        return None
-
-    def _validate_fields(self, data_fields: list) -> list:
-        values = []
-        serializer = self.get_serializer_class()
-        fields = list(serializer().fields.keys())
-        for f in data_fields:
-            if f in fields:
-                values.append(f)
-            else:
-                raise InvalidFieldsParam(
-                    {"status": "error", "message": f"invalid field - {f}"}
-                )
-        return values
-
-    def validate_request_data(self, request) -> dict:
-        admin = self.get_check_admin(request)
-        if not admin:
-            raise PermissionDenied(
-                {
-                    "status": "error",
-                    "message": "You don't have permissions for this endpoint.",
-                }
-            )
-        data = request.data
-        integration_id = data.get("integration_id")
-
-        if not integration_id:
-            return (
-                InvalidDateParams(
-                    {"status": "error", "message": "Miss integration id."}, status=422
-                ),
-            )
-
-        values = list()
-        if 'fields' in data:
-            values = self._validate_fields(data['fields'])
-        self.check_log()
-        return {
-            'data': data,
-            'integration_id': integration_id,
-            'admin': admin,
-            'platform_id': request.GET['platform_id'],
-            'values': values,
-        }
-
-
 class BaseAggregationComparisonAPIView(CredentialMixin, APIView):
     check_credential = False
-    aggregation_manager = None
 
-    def get_aggregation_manager(self):
-        if self.aggregation_manager:
-            return self.aggregation_manager
-        raise NotImplementedError('aggregation_manager must be implemented.')
+    def generate_aggregation_result(
+        self, request_data: dict, access_token: str
+    ) -> dict:
+        raise NotImplementedError('`generate_aggregation_result` must be implemented.')
 
     def post(self, request):
         access_token = request.META['HTTP_AUTHORIZATION'].split(' ')[1]
         if 'data' not in request.data:
             raise PermissionDenied('miss data or executetoken')
-        agg_manager = self.get_aggregation_manager()(request.data, access_token)
-        result = agg_manager.aggegation_data()
+        result = self.generate_aggregation_result(request.data, access_token)
         return Response({'result': result})
